# X-IPE Application Architecture

Presentation
Jinja2 Templates
index.html
settings.html
base.html
Frontend JS Modules
Workplace Manager
Terminal
Stage Toolbox
Content Renderer
Event Bus
Business Logic
Core Services
FileService
IdeasService
TerminalService
Configuration Services
ConfigService
SettingsService
ToolsConfigService
Extension Services
ThemesService
SkillsService
Data
Project Files
📁 docs/
📁 src/
📁 static/
Configuration
📄 x-ipe-docs/config/tools.json
📄 .x-ipe.yaml
Session Data
📁 instance/